BEGIN TRANSACTION;
CREATE TABLE `account` (
  `id` bigint(20) NOT NULL PRIMARY KEY ON CONFLICT REPLACE,
  `fiLoginId` bigint(20) NOT NULL REFERENCES `fi_login` (`id`),
  `accountName` varchar(255) NOT NULL default '',
  `lastModified` datetime NOT NULL default 0,
  `accountType` int(11) NOT NULL,
  `balance` decimal(15,5) NOT NULL,
  `status` int(11) NOT NULL,
  `subAccountType` varchar(255),
  `numTransactions` int(10),
  `isZillow` int (1), 
  `linkedAccountId` bigint(20), 
  `isHiddenLinkedAccount` int(1), 
  `availableBalance` decimal(15,5), 
  `isHiddenFromPlanningTrends` int (1),
  `openingBalance` decimal(15,5) NOT NULL default 0,
  `openingBalanceDate` datetime NOT NULL default 0
);
  
CREATE TABLE `advice` (
	 `id` bigint(20) NOT NULL PRIMARY KEY ON CONFLICT REPLACE,
	 `offerId` bigint(20) NOT NULL,
	 `priority` int(11) NOT NULL,
	 `isIgnored` int(1),
	 `viewed` int(1),
	 `headline` varchar(255,0) NOT NULL,
	 `body` varchar(1024) NOT NULL,
	 `callToAction` varchar(255) NOT NULL,
	 `creationTime` datetime NOT NULL,
	 `offerLink` varchar(1024),
	 `offerLink2` varchar(1024),
	 `largeImage` varchar(255) NOT NULL,
	 `extralargeImage` varchar(255),
	 `name` varchar(255),
	 `hidden` int(1),
     `displayMode` int(1)
);

CREATE TABLE `alert` (
	`id` bigint(15) NOT NULL PRIMARY KEY ON CONFLICT REPLACE, 
	`accountId` bigint(20) REFERENCES `account` (`id`), 
	`details` varchar(255), 
	`categoryId` bigint(20), 
	`transactionId` bigint(20), 
	`date` datetime, 
	`lastSeen` datetime, 
	`viewed` int(1), 
	`alertType` int(10),
	`alertTypeString` varchar(50),
	`creationTime` datetime
	);

CREATE TABLE `attributes` (
  `key` varchar(255) NOT NULL PRIMARY KEY ON CONFLICT REPLACE,
  `value` varchar(255) NOT NULL default ''
);

CREATE TABLE `budget` (
	`id` bigint(20) NOT NULL PRIMARY KEY ON CONFLICT REPLACE,
	`amount` decimal(15,5) NOT NULL,
	`budgetAmount` decimal(15,5) NOT NULL,
	`status` int(11) NOT NULL,
	`categoryId` int(11) NOT NULL REFERENCES `category` (`id`),
	`budgetPerformance` int(11),
	`dateString` varchar(8),
	`type` varchar(2),
	`paymentDateString` varchar(8),
	`rollover` int(1),
	`totalAmount` decimal(15,5),
	`period` int(11)
	);

CREATE TABLE `budget_overall` (
  `id` bigint(20) NOT NULL PRIMARY KEY ON CONFLICT REPLACE,
  `performanceStatus` bigint(20)
);

CREATE TABLE "category" (
	 "id" bigint(15,0) NOT NULL,
	 "categoryName" varchar(255,0) NOT NULL,
	 "softDeleted" varchar(1,0) NOT NULL,
	 "depth" int(1,0) NOT NULL,
	 "parentId" int(8,0),
	 "googlePlacesCategory" varchar(255,0),
	 "bitFlags" integer(4,0) NOT NULL,
	 "type" integer(1,0) NOT NULL,
     "family" integer(1) NOT NULL DEFAULT 0,
	 "mintRefId" integer(8,0) NOT NULL,
	 "lastModified" datetime NOT NULL default 0,
	PRIMARY KEY("id") ON CONFLICT REPLACE,
	FOREIGN KEY ("parentId") REFERENCES "category" ("id")
);

CREATE TABLE `event_reminders` (
  `id` INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  `serverID` TEXT,
  `descriptionString` TEXT,
  `amount` NUMERIC,
  `paymentState` TEXT,
  `type` TEXT,
  `createdBy` TEXT,
  `amountVaries` NUMERIC,
  `startDate` NUMERIC,
  `status` TEXT,
  `stage` TEXT,
  `nextReminderDate` NUMERIC,
  `merchantName` TEXT,
  `merchantServerID` TEXT,
  `frequencyNumber` INTEGER,
  `frequencyUnit` TEXT
);

CREATE INDEX event_reminder_serverID on event_reminders(serverID);

CREATE TABLE `fi_login` (
  `id` bigint(15) NOT NULL PRIMARY KEY ON CONFLICT REPLACE,
  `status` bigint(20) NOT NULL,
  `lastUpdateDate` datetime,
  `fiName` varchar(255),
  `lastUpdated` varchar(255),
  `mintStatus` int(10), 
  `errorMessage` varchar(255), 
  `errorContent` varchar(1024), 
  `phone` varchar(32), 
  `url` varchar(255), 
  `logo` varchar(128), 
  `csMessage` varchar(255), 
  `csMessageLink` varchar(255),
  `blobCredentials` text,
  `provideCredentials` int(1),
  `isManual` int(1)
);

CREATE TABLE `refresh` (
  `lastSuccessfulRefresh` datetime
);

CREATE TABLE `spending` (
  `id` bigint(20) NOT NULL PRIMARY KEY ON CONFLICT REPLACE,
  `expense` decimal(15,5) NOT NULL,
  `income` decimal(15,5) NOT NULL
);

CREATE TABLE `transaction_bankcc` (
	`id` bigint(15) NOT NULL ,  
	`type` int (10) NOT NULL,  
	`accountId` bigint(15) NOT NULL REFERENCES `account` (`id`),  
	`description` varchar(255) NOT NULL,  
	`amount` decimal (15,5) NOT NULL,  
	`categoryId` int (10)  NOT NULL REFERENCES `category` (`id`),  
	`pending` int (1),  
	`duplicate` int(1),  
	`includeInCategoryReport` int(1),  
	`includeInMerchantReport` int(1),  
	`datePostedStringInt` int(8),
	`userNote` varchar(255),  
	`inferredCategoryId` int (10)  NOT NULL default 0 REFERENCES `category` (`id`),  
	`originalDescription` varchar(255),  
	`version` int(20),  
	`originalDatePostedStringInt` int(8),  
	`manualTransactionType` int(10), 
	`commonMerchantId` int(11), 
	`serverModTime` BIGINT, 
	`splitParentId` bigint(15),
	`isSoftDeletedSplitParent` int(1),
	`percent` decimal(6,3) NOT NULL default 0,
    `isSplitByPercent` int(1) NOT NULL default 0,
    `documentURI` varchar(255),
	constraint "id_type" UNIQUE (id, type) ON CONFLICT REPLACE
);
	
CREATE INDEX datePosted on transaction_bankcc(datePostedStringInt);
CREATE INDEX pending ON transaction_bankcc(pending);

CREATE TABLE `transaction_manual` (
  `transactionId` bigint(15) NOT NULL,
  `transactionType` int(10) NOT NULL,
  `manualTransactionType` int (10) NOT NULL,
  `amount` decimal (15,5) NOT NULL,
  `merchantId` bigint(15) NOT NULL REFERENCES `transaction_merchant` (`id`),
  `latitude` decimal (15,5) default NULL,
  `longitude` decimal (15,5) default NULL,
  `horizAccuracy` decimal (15,5) default NULL,
  FOREIGN KEY(`transactionId`, `transactionType`) REFERENCES `transaction_bankcc` (`id`,`type`),   
  constraint "id_type" UNIQUE (transactionId, TransactionType) ON CONFLICT REPLACE
);

CREATE TABLE `transaction_merchant` (
  `id` INTEGER PRIMARY KEY ON CONFLICT REPLACE,
  `categoryId` int (10)  NOT NULL REFERENCES `category` (`id`),
  `description` varchar(255)
);

CREATE TABLE `transaction_usertag` (
	`transactionId` bigint(15) NOT NULL, 
	`transactionType` int(10) NOT NULL, 
	`tagId` bigint(15) NOT NULL, 
	FOREIGN KEY(`transactionId`, `transactionType`) REFERENCES `transaction_bankcc` (`id`,`type`),
	constraint "id_type_tag" UNIQUE(`transactionId`, `transactionType`,`tagId`) ON CONFLICT REPLACE
);

CREATE TABLE `credit_report`
(
	`id` INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
	`vendor` INTEGER,
	`refreshDate` datetime NOT NULL,
	`nextRefreshDate` datetime NOT NULL,
	`creditScore` INTEGER NOT NULL,
	`bandId` INTEGER
);

CREATE TABLE `credit_report_aggregates`
(
	`id` INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
	`reportId` INTEGER NOT NULL,
	`aggregate` text,
	`key` text,
	`value` text
);

CREATE TABLE `credit_report_bands` (
`id` INTEGER PRIMARY KEY AUTOINCREMENT,
`aggregate` TEXT,
`bandId` INTEGER NOT NULL,
`title` TEXT,
`startValue` INTEGER,
`endValue` INTEGER,
`color` TEXT
);

CREATE TABLE `credit_report_tips` (
`id` INTEGER PRIMARY KEY AUTOINCREMENT,
`tipId` INTEGER NOT NULL,
`bandKey` INTEGER NOT NULL,
`title` TEXT,
`text` TEXT
);

CREATE TABLE `user` (
  `id` bigint(20) NOT NULL PRIMARY KEY  ON CONFLICT REPLACE,
  `loginName` varchar(255) NOT NULL default ''
);

CREATE TABLE `user_tag` (
  `id` bigint(15) NOT NULL PRIMARY KEY ON CONFLICT REPLACE,
  `name` varchar(30) NOT NULL,
  `isHiddenFromPlanningTrends` int (1),
  `isHidden` int(1) NOT NULL default 0
  );

CREATE TABLE `version` (
  `version` decimal(5,20) NOT NULL PRIMARY KEY  ON CONFLICT REPLACE
);

CREATE TABLE `blog_items` (
	`id` INTEGER NOT NULL PRIMARY KEY  ON CONFLICT REPLACE,
	`title` varchar(50) NOT NULL,
	`subtitle` varchar(100) NOT NULL,
	`origLink` varchar(50) NOT NULL,
	`imageUrl` varchar(50),
	`category` varchar(20),
	`creator` varchar(20),
	`content` varchar(100),
	`pubDate` datetime NOT NULL,
	`hidden` int(1) NOT NULL default 0,
	`viewed` int(1) NOT NULL default 0
);

COMMIT;
